%close all
clear all

% constant
c=3e8;

% analysis parameters
wl2w1=370; % restrict the analysis from the wavelength
wl2w2=440; % restrict the analysis to the wavelength
NbSp=32;   % number of spectral points used in the reconstruction

measurement='ChirpScan_20190823_1733';
A=importdata(['./Simu/',measurement,'/MAP.txt']);
Spth=importdata(['./Simu/',measurement,'/SpectrumTh.txt']);
Tpth=importdata(['./Simu/',measurement,'/TemporalTh.txt']);

phi2CS  = A(1,[2:end]);          % temporal experimental axis
wl2exp  = A([2:end],1);          % spectral experimental axis (2w)
CSexp   = A([2:end],[2:end]);    % CS trace

% add experimental noise (test of the robustness)
CSexp=CSexp+max(max(CSexp))*0.0*randn(size(CSexp));

figure(1);
pcolor(phi2CS,wl2exp,CSexp);
xlabel('Chirp introduced (fs^2)');ylabel('wavelength (nm)');shading flat;title('Chirp Scan trace')
ylim([wl2w1 wl2w2])

%% restrict the analysis to a resonable spectral region
[val, pos1]=min(abs(wl2exp-wl2w1));
[val, pos2]=min(abs(wl2exp-wl2w2));
CStemp=CSexp([pos1:pos2],:);
wl2temp=wl2exp(pos1:pos2);
nu2=c./(wl2temp*1e-9);dnu2=diff(nu2);dnu2(end+1)=dnu2(end);
for ind=1:length(wl2temp)
    CStemp(ind,:)=CStemp(ind,:)./abs(dnu2(ind));
end

%% make a constant step in frequency
nu2reg=[min(nu2):(max(nu2)-min(nu2))/(2*NbSp):max(nu2)]';dnu2reg=nu2reg(2)-nu2reg(1);
for ind=1:length(phi2CS)
    CSreg(ind,:)=interp1(nu2,CStemp(:,ind),nu2reg,'spline');
end
dt2=1/(max(nu2reg)-min(nu2reg))*1e15*2;
t2=[1:length(nu2reg)]*dt2;t2=t2-mean(t2);
dt2sd=1/(max(nu2reg)-min(nu2reg))*1e15*2/5;
t2sd=[1:5*length(nu2reg)]*dt2sd;t2sd=t2sd-mean(t2sd);





%% Reconstruciton using the two SHG measurements OE_21_24879_(2013) 
figure(2);clf
subplot(2,2,1)
pcolor(phi2CS,c./nu2reg*1e9,CSreg');
xlabel('Chirp introduced (fs^2)');ylabel('wavelength (nm)');shading flat;title('Chirp Scan trace')
ylim([wl2w1 wl2w2])

Ip=CSreg(end,:);% selection of the two most separated measurement
Im=CSreg(1,:);

% reconstruction of the amplitude and the phase
pt2phi0=(phi2CS(end)-phi2CS(1))*1e-30/2;
pt2Isp=sqrt(2*pt2phi0 * (Ip.*Im)./(Ip+Im));                                                 % reconstruciton of the spectral intensity
pt2phipp=pt2phi0*(Ip-Im)./(Ip+Im);                                                          % reconstruction of the second derivative of the pahse
pt2phip =cumsum(pt2phipp)*dnu2reg*pi;   pt2phip=pt2phip-sum(pt2phip.*pt2Isp)/sum(pt2Isp);   % reconstruction of the first derivative of the pahse
pt2phi  =cumsum(pt2phip) *dnu2reg*pi;   pt2phi =pt2phi -sum(pt2phi.* pt2Isp)/sum(pt2Isp);   % reconstruction of the  pahse

subplot(2,2,4); % plot spectrum
plot(c./nu2reg*2e9,pt2Isp/max(pt2Isp),Spth(:,1),Spth(:,2),'k')
xlabel('Wavelength (nm)');ylabel('Reconstructed intensity (arb. unit)')
xlim(2*[wl2w1 wl2w2])
subplot(2,2,2)
plot(c./nu2reg*2e9,pt2phi,Spth(:,1),Spth(:,3),'k')
xlabel('Wavelength (nm)');ylabel('Reconstructed phase (rad)')
xlim(2*[wl2w1 wl2w2])

% plot temporal
pt2E=sqrt(pt2Isp).*exp(-i*pt2phi);
pt2Esd=[pt2E*0 pt2E*0 pt2E pt2E*0 pt2E*0]; % fourier smooth
Etreconst2pt=fftshift(fft(fftshift(pt2Esd)));
Itreconst2pt=abs(Etreconst2pt).^2;
Itreconst2ptN=Itreconst2pt/max(Itreconst2pt);
subplot(2,2,3)
hold on
plot(Tpth(:,1),Tpth(:,2),'k');
plot(t2sd,Itreconst2ptN)
xlim(100*[-1 1]);xlabel('Time (fs)')





%% Reconstruction with lorentzian fit Canova et al. + OE_16_592_(2008)
figure(3);clf
subplot(2,2,1)
pcolor(phi2CS,c./nu2reg*1e9,CSreg');
xlabel('Chirp introduced (fs^2)');ylabel('wavelength (nm)');shading flat;title('Chirp Scan trace')
ylim([wl2w1 wl2w2])

% reconstruction of the spectral amplitude
LorIsp=sqrt(abs(sum(CSreg)));
subplot(2,2,4); % plot spectrum
plot(c./nu2reg*2e9,LorIsp/max(LorIsp),Spth(:,1),Spth(:,2),'k')
xlabel('Wavelength (nm)');ylabel('Reconstructed intensity (arb. unit)')
xlim(2*[wl2w1 wl2w2])

% reconstruction of the phase
for ind=1:length(nu2reg)
    y=CSreg(:,ind);% Intensity dependence for a given wavelength
    cp(1)=max(y);                   % intensity
    cp(2)=sum(y.*phi2CS')/sum(y);    % position of the max of the contribution
    cp(3)=300;
    cp(4)=min(y);
    [f,p,kvg,iter,corp,covp,covr,stdresid,Z,r2]=leasqr(phi2CS',y,cp,'CSdpd',0.00005,30);
    stdev=sqrt(diag(covp));  %Uncertainity on the parameters
%     figure(30) % visualization of individual fit to improve the initials parameters
%     plot(phi2CS,y,'b+',phi2CS,f,'r',phi2CS,CSdpd(phi2CS,cp))
%     figure(3)
    LorPhipp(ind)=p(2);
    if (LorPhipp(ind)<min(phi2CS))
        LorPhipp(ind)=min(phi2CS);
    end
    if (LorPhipp(ind)>max(phi2CS))
        LorPhipp(ind)=max(phi2CS);
    end          
end
subplot(2,2,1)
line(LorPhipp,c./nu2reg*1e9,'color','white');

LorPhip =cumsum(LorPhipp*1e-30)*dnu2reg*pi;   LorPhip=LorPhip-sum(LorPhip.*LorIsp)/sum(LorIsp);   % reconstruction of the first derivative of the pahse
LorPhi  =cumsum(LorPhip)       *dnu2reg*pi;   LorPhi =LorPhi -sum(LorPhi.* LorIsp)/sum(LorIsp);   % reconstruction of the  pahse
subplot(2,2,2)
plot(c./nu2reg*2e9,LorPhi,Spth(:,1),Spth(:,3),'k')
xlabel('Wavelength (nm)');ylabel('Reconstructed phase (rad)')
xlim(2*[wl2w1 wl2w2])

% plot temporal
LorE=sqrt(LorIsp).*exp(-i*LorPhi);
LorEsd=[LorE*0 LorE*0 LorE LorE*0 LorE*0]; % fourier smooth
EtreconstLor=fftshift(fft(fftshift(LorEsd)));
ItreconstLor=abs(EtreconstLor).^2;
ItreconstLorN=ItreconstLor/max(ItreconstLor);
subplot(2,2,3)
hold on
plot(Tpth(:,1),Tpth(:,2),'k');
plot(t2sd,ItreconstLorN)
xlim(100*[-1 1]);xlabel('Time (fs)')
