%close all
clear all

measurement='FROG_20190823_1734';
A=importdata(['./Simu/',measurement,'/MAP.txt']);
Spth=importdata(['./Simu/',measurement,'/SpectrumTh.txt']);
Tpth=importdata(['./Simu/',measurement,'/TemporalTh.txt']);

tFROG  = A(1,[2:end]);          % temporal experimental axis
wl2    = A([2:end],1);          % spectral experimental axis (2w)
FROG   = A([2:end],[2:end]);    % FROG trace

% Add experimental noise (test robustness)
FROG=FROG+max(max(FROG))*0.0*randn(size(FROG));

figure(1);clf
subplot(2,2,3)
pcolor(tFROG,wl2,FROG);
xlabel('Time (fs)');ylabel('wavelength (nm)');shading flat;title('FROG trace')
ylim([350 450])

autoco=sum(FROG);
subplot(2,2,1);hold on
plot(tFROG,autoco/max(autoco),'ko');
xlabel('Time (fs)');ylabel('Intensity (arb. unit)');shading flat;title('Autocorrelation')

Iwl2=sum(FROG,2);
subplot(2,2,4)
plot(Iwl2/max(Iwl2),wl2,'k');
xlabel('Intensity (arb. unit)');ylabel('wavelength (nm)');shading flat;title('Integrated SHG spectrum')
ylim([350 450])

%% analysis of the autocorrelation trace
% Initial Guess
figure(1);
c(1)=max(autoco)-min(autoco);   % amplitude of the autocorrelation
c(2)=3;                         % center of the autorrelation trace i.e. 0 is not a good initial parameter
c(3)=20;                        % duration of the autoco (fs)
c(4)=min(autoco);               % Background
[f,p,kvg,iter,corp,covp,covr,stdresid,Z,r2]=leasqr(tFROG',autoco',c,'Gauss',0.00005,30);
stdev=sqrt(diag(covp));  %Uncertainity on the parameters
subplot(2,2,1);
plot(tFROG,f/max(autoco),'r');
title(['Autoco duration/sqrt(2)=',num2str(p(3)/sqrt(2)),'\pm',num2str(stdev(3)/sqrt(2))])

%% extract the spectral intensity
Iwl=sqrt(abs(Iwl2));
Iwl=Iwl-mean(Iwl([1:10,end-10:end]));
wl=2*wl2;

%figure(2);clf
subplot(2,2,2);hold on
plot(Spth(:,1),Spth(:,2),'b')
plot(wl,Iwl./max(Iwl),'k')
xlabel('wavelength (nm)');ylabel('spectral intensity'),xlim([700 900])

% Matlab code to analyse the FROG trance avaliable on the webpage : http://frog.gatech.edu/code.html