%close all
clear all



% constant
c=3e8;

% analysis parameters
wl2w1=370; % restrict the analysis from the wavelength
wl2w2=440; % restrict the analysis to the wavelength
NbSp=32;   % number of spectral points used in the reconstruction

measurement='MIIPS_20190823_1734';
A=importdata(['./Simu/',measurement,'/MAP.txt']);
Spth=importdata(['./Simu/',measurement,'/SpectrumTh.txt']);
Tpth=importdata(['./Simu/',measurement,'/TemporalTh.txt']);
Param=importdata(['./Simu/',measurement,'/Param.txt']);
Freq=Param(1);Ampl=Param(2);lambda0=Param(3);
nu0=3e8/lambda0;

PhiScan  = A(1,[2:end]);          % temporal experimental axis
wl2exp  = A([2:end],1);          % spectral experimental axis (2w)
MIIPSexp   = A([2:end],[2:end]);    % CS trace

% add experimental noise (test of the robustness)
MIIPSexp=MIIPSexp+max(max(MIIPSexp))*0.0*randn(size(MIIPSexp));

figure(1);
pcolor(PhiScan,wl2exp,MIIPSexp);
xlabel('Chirp introduced (fs^2)');ylabel('wavelength (nm)');shading flat;title('Chirp Scan trace')
ylim([wl2w1 wl2w2])

%% restrict the analysis to a resonable spectral region
[val, pos1]=min(abs(wl2exp-wl2w1));
[val, pos2]=min(abs(wl2exp-wl2w2));
CStemp=MIIPSexp([pos1:pos2],:);
wl2temp=wl2exp(pos1:pos2);
nu2=c./(wl2temp*1e-9);dnu2=diff(nu2);dnu2(end+1)=dnu2(end);
for ind=1:length(wl2temp)
    CStemp(ind,:)=CStemp(ind,:)./abs(dnu2(ind));
end

%% make a constant step in frequency
nu2reg=[min(nu2):(max(nu2)-min(nu2))/(2*NbSp):max(nu2)]';dnu2reg=nu2reg(2)-nu2reg(1);
for ind=1:length(PhiScan)
    MIIPSreg(ind,:)=interp1(nu2,CStemp(:,ind),nu2reg,'spline');
end
dt2=1/(max(nu2reg)-min(nu2reg))*1e15*2;
t2=[1:length(nu2reg)]*dt2;t2=t2-mean(t2);
dt2sd=1/(max(nu2reg)-min(nu2reg))*1e15*2/5;
t2sd=[1:5*length(nu2reg)]*dt2sd;t2sd=t2sd-mean(t2sd);


% prepare analysis
Mphi=PhiScan'*(nu2reg'*0+1);
Mnu2reg=(PhiScan'*0+1)*nu2reg';
maskA=heaviside(Mphi+2*pi*Freq*(Mnu2reg/2-nu0)-  pi/2).*(1-heaviside(Mphi+2*pi*Freq*(Mnu2reg/2-nu0)-3*pi/2));
maskB=heaviside(Mphi+2*pi*Freq*(Mnu2reg/2-nu0)-3*pi/2).*(1-heaviside(Mphi+2*pi*Freq*(Mnu2reg/2-nu0)-5*pi/2));
MIIPSregA=MIIPSreg.*maskA;
MIIPSregB=MIIPSreg.*maskB;


%% Reconstruction with lorentzian fit Canova et al. + OE_16_592_(2008)
figure(3);clf
subplot(2,2,1)
pcolor(PhiScan,c./nu2reg*1e9,MIIPSreg');
xlabel('Phase of the phase (rad)');ylabel('wavelength (nm)');shading flat;title('Chirp Scan trace')
ylim([wl2w1 wl2w2])

% reconstruction of the spectral amplitude
Isp=sqrt(abs(sum(MIIPSreg)));
subplot(2,2,4); % plot spectrum
plot(c./nu2reg*2e9,Isp/max(Isp),Spth(:,1),Spth(:,2),'k')
xlabel('Wavelength (nm)');ylabel('Reconstructed intensity (arb. unit)')
xlim(2*[wl2w1 wl2w2])

% reconstruction of the second derivative of the spectral phase
[vval,posPhiA]=max(MIIPSregA);PhiA=PhiScan(posPhiA);
[vval,posPhiB]=max(MIIPSregB);PhiB=PhiScan(posPhiB);
subplot(2,2,1)
line(PhiA,c./nu2reg*1e9,'color','white','linestyle','-');
line(PhiB,c./nu2reg*1e9,'color','white','linestyle','-');
Phipp=-Ampl*Freq^2*(PhiB-PhiA-pi)/4;

% reconstruction of the spectral phase
Phip =cumsum(Phipp)*dnu2reg*pi;   Phip=Phip-sum(Phip.*Isp)/sum(Isp);   % reconstruction of the first derivative of the pahse
Phi  =cumsum(Phip)       *dnu2reg*pi;   Phi =Phi -sum(Phi.* Isp)/sum(Isp);   % reconstruction of the  pahse
subplot(2,2,2)
plot(c./nu2reg*2e9,Phi,Spth(:,1),Spth(:,3),'k')
xlabel('Wavelength (nm)');ylabel('Reconstructed phase (rad)')
xlim(2*[wl2w1 wl2w2])

% plot temporal
LorE=sqrt(Isp).*exp(-i*Phi);
LorEsd=[LorE*0 LorE*0 LorE LorE*0 LorE*0]; % fourier smooth
EtreconstLor=fftshift(fft(fftshift(LorEsd)));
ItreconstLor=abs(EtreconstLor).^2;
ItreconstLorN=ItreconstLor/max(ItreconstLor);
subplot(2,2,3)
hold on
plot(Tpth(:,1),Tpth(:,2),'k');
plot(t2sd,ItreconstLorN)
xlim(100*[-1 1]);xlabel('Time (fs)')
