%close all
clear all


%% definition of basic vectors
c=3e8;
lambda0=800e-9;
omega0=2*pi*c/lambda0;

omega=omega0*[1.5:-0.001:0.5]; if (mod(length(omega),2)~=1);omega=omega([2:end]);end
nu=omega/(2*pi);
domega=min(diff(omega));
largomeg=omega0*0.05;% spectral width
lambda=2*pi*c./omega;
wl800=2*pi*c./omega*1e9;
OmO=(omega-omega0);
dt=1./(max(nu)-min(nu))*1e15;
t=[1:length(nu)]*dt;t=t-mean(t);
omegazl=[2*omega(1):omega(2)-omega(1):2*omega(end)];
dt2=1/(max(omegazl/(2*pi))-min(omegazl/(2*pi)))*1e15;
t2=[1:length(omegazl)]*dt2;t2=t2-mean(t2);
%% description of the spectral amplitude
Esp=exp(-(omega-omega0).^2/largomeg^2);

    
%% description of the spectral phase in terms of Dispersion order   
order2=500;
order3=10000;
order4=00000;
order5=000000;
step=pi*0;

phaseinit=          OmO.^2*order2*1e-30/factorial(2);
phaseinit=phaseinit+OmO.^3*order3*1e-45/factorial(3);
phaseinit=phaseinit+OmO.^4*order4*1e-60/factorial(4);
phaseinit=phaseinit+OmO.^5*order5*1e-75/factorial(5);

phaseinit=phaseinit+step*heaviside(omega-omega0);

% combine spectral amplitude and phase
Esp=Esp.*exp(i*phaseinit);

Esp2=conv(Esp,flipud(Esp));% calulation of the second harmonic spectrum

Et=fftshift(fft(fftshift(Esp)));    % temporal profile
Et2=fftshift(fft(fftshift(Esp2)));  % Temporal profile 2w

% normalize map in wavelength
lbd2=2*pi*c./omegazl*1e9;
dlbd2=diff(lbd2);dlbd2(end+1)=dlbd2(end);
Esp2=Esp2./dlbd2;

%% Show the result of the simulation
lbdplt=2*pi*c./omega*1e9;
dlbdplt=diff(lbdplt);dlbdplt(end+1)=dlbdplt(end);
Ilambda=abs(Esp).^2./dlbdplt;Ilambda=Ilambda/max(Ilambda);
figure(1)
subplot(2,3,1)
plot(lbdplt,Ilambda,'r');
xlabel('wavelength [nm]')
ylabel('Spectral intensity')
xlim([700 900])
title('Spectrum fundamental')

subplot(2,3,4)
plot(lbdplt,angle(Esp),'r');
xlabel('wavelength [nm]')
ylabel('Spectral phase')
ylim([-3.2 3.2])
xlim([700 900])

It =abs(Et ).^2;It =It/max(It );
It2=abs(Et2).^2;It2=It2/max(It2);
subplot(2,3,2)
plot(t,It,'r',t2,It2,'b');
xlabel('time [fs]')
ylabel('temporal intensity')
xlim(150*[-1 1])
title('Temporal')

subplot(2,3,5)
plot(t,angle(Et),'r',t2,angle(Et2),'b--');
xlabel('time [fs]')
ylabel('temporal phase [rad]')
xlim(150*[-1 1])
ylim(pi*[-1 1])

subplot(2,3,3)
plot(lbd2,abs(Esp2).^2);
title('Second harmonic')
xlim([350 450])
xlabel('wavelength [nm]')

subplot(2,3,6)
plot(lbd2,angle(Esp2));
title('Second harmonic')
xlim([350 450])
xlabel('wavelength [nm]')
