close all
clear all

% define the kind of measurement you are interested in
method=4;   % 1= chirp scan; 2 dispersion scan; 3=MIIPS; 4=FROG; 

%% definition of basic vectors
c=3e8;
lambda0=800e-9;
omega0=2*pi*c/lambda0;

omega=omega0*[1.7:-0.001:0.5];
nu=omega/(2*pi);
domega=min(diff(omega));
largomeg=omega0*0.05;% spectral width
lambda=2*pi*c./omega;
wl800=2*pi*c./omega*1e9;
OmO=(omega-omega0);
dt=1./(max(nu)-min(nu))*1e15;
t=[1:length(nu)]*dt;t=t-mean(t);

%% description of the spectral amplitude
Esp=exp(-(omega-omega0).^2/largomeg^2);
    omegazl=[2*omega(1):omega(2)-omega(1):2*omega(end)];

    
%% description of the spectral phase in terms of Dispersion order   
order2=500;
order3=10000;
order4=00000;
order5=00000;
step=pi*0;

phaseinit=          OmO.^2*order2*1e-30/factorial(2);
phaseinit=phaseinit+OmO.^3*order3*1e-45/factorial(3);
phaseinit=phaseinit+OmO.^4*order4*1e-60/factorial(4);
phaseinit=phaseinit+OmO.^5*order5*1e-75/factorial(5);

phaseinit=phaseinit+step*heaviside(omega-omega0);

% combine spectral amplitude and phase
Esp=Esp.*exp(i*phaseinit);

Et=fftshift(fft(fftshift(Esp)));    % temporal profile


%% calculation of the method
if (method==1)      % chirp Scan methods
    param=[-3000:20:3000];     
    for ind=1:1:length(param)
        phasesup=OmO.^2*param(ind)/2*1e-30;   
        Esploc=Esp.*exp(-i*phasesup);
        Mconv(:,ind)=conv(Esploc,flipud(Esploc));
    end
    MAP=abs(Mconv).^2;
end

if (method==2)                  % d Scan methods
    param=[-40:0.2:40];         % in mm of glass
    for ind=1:1:length(param)
        phasesup= OmO.^2*param(ind)*36.16/2*1e-30 ...
                 +OmO.^3*param(ind)*27.47/6*1e-45;   % for fuse silica @800nm 36.16fs^2 ; 27.47fs^3 and %https://www.newport.com/n/the-effect-of-dispersion-on-ultrashort-pulses
        Esploc=Esp.*exp(-i*phasesup);
        Mconv(:,ind)=conv(Esploc,flipud(Esploc));
    end
    MAP=abs(Mconv).^2;
end


if (method==3)      % MIIPS Method
    Freq=25e-15;
    Ampl=5;
    param=[0:pi/50:3*pi];
    MOmO=OmO'*(param*0+1);
    Mparam=(OmO'*0+1)*param;
    phasesup=Ampl*sin(MOmO*Freq+Mparam);
    for ind=1:1:length(param)
        Esploc=Esp.*exp(-i*phasesup(:,ind)');
        Mconv(:,ind)=conv(Esploc,flipud(Esploc));
    end
    MAP=abs(Mconv).^2;
end


if (method==4)      % FROG Method
    param=[-100:1:100];
    phasesup=OmO'*param/2*1e-15;%devided by 2 because we associate half of the delay for eacy arm

    for ind=1:1:length(param)
        Esploc1=Esp.*exp(-i*phasesup(:,ind)');
        Esploc2=Esp.*exp(i*phasesup(:,ind)');        
        Mconv(:,ind)=conv(Esploc1,flipud(Esploc2));
    end
    MAP=abs(Mconv).^2;
end

% normalize map in wavelength
lbd2=2*pi*c./omegazl*1e9;
dlbd2=diff(lbd2);dlbd2(end+1)=dlbd2(end);
Mdlbd2=dlbd2'*(param*0+1);
MAP=MAP./Mdlbd2;

%% Show the result of the simulation
lbdplt=2*pi*c./omega*1e9;
dlbdplt=diff(lbdplt);dlbdplt(end+1)=dlbdplt(end);
Ilambda=abs(Esp).^2./dlbdplt;Ilambda=Ilambda/max(Ilambda);
figure(1)
subplot(2,2,1)
plot(lbdplt,Ilambda,'r');
xlabel('wavelength [nm]')
ylabel('Spectral intensity')
xlim([700 900])
title('Spectral')

subplot(2,2,3)
plot(lbdplt,angle(Esp),'r');
xlabel('wavelength [nm]')
ylabel('Spectral phase')
ylim([-3.2 3.2])
xlim([700 900])

It=abs(Et).^2;It=It/max(It);
subplot(2,2,2)
plot(t,It,'r');
xlabel('time [fs]')
ylabel('temporal intensity')
xlim(100*[-1 1])
title('Temporal')

subplot(2,2,4)
pcolor(param,lbd2,MAP);
title('Simulated MAP')
shading flat
ylim([380 420])
ylabel('wavelength [nm]')
switch (method)
    case 1; xlabel('Quadratic phase [ fs^2 ]');     Expname='ChirpScan';
    case 2; xlabel('mm of fuse silica [ mm ]');     Expname='dScan';
    case 3; xlabel('phase of the sinus [ rad ]');   Expname='MIIPS';
    case 4; xlabel('Delay [ fs ]');                 Expname='FROG';
end


%% save the simulation in a directory
% prepare a directory for automatic recording
ck=clock;
dirname=[Expname,'_',num2str(ck(1)),num2str(ck(2),'%0.2d'),num2str(ck(3),'%0.2d'),'_',num2str(ck(4),'%0.2d'),num2str(ck(5),'%0.2d')];
mkdir(['./Simu/',dirname]);
outsp=[lbdplt',Ilambda',angle(Esp)'];
save(['./Simu/',dirname,'/SpectrumTh.txt'],'outsp','-ascii');
outtmp=[t',It'];
save(['./Simu/',dirname,'/TemporalTh.txt'],'outtmp','-ascii')
out1=[0 lbd2];
out2=[param',MAP'];
out3=[out1' out2'];
save(['./Simu/',dirname,'/MAP.txt'],'out3','-ascii')
saveas(gcf,['./Simu/',dirname,'/Simu.png'],'png')
if (method==3)
    out4=[Freq Ampl lambda0];
    save(['./Simu/',dirname,'/Param.txt'],'out4','-ascii')
end