clear all
close all

global VMIEmax MeanEvent cx cy resolution

% general parameters if the experiment
VMIEmax=4;              % maximum of energy of the VMI detection eV (depends on the voltage of the Repeller electrode)
MeanEvent=1e4;          % if =0 -> it gives the probability density; otherwise give the mean number of event per canal
cx=202;                 % Center of the VMI image among x
cy=147;                 % Center of the VMI image among y
resolution=[400 300];   % resolution of the camera

%lambdapump=266;         % wavelength of the pump in nm to populate the A band
lambdapump=200;        % wavelength of the pump in nm to populate the B band

lambdaprobe=333;        % wavelength of the probe to detect CH3 fragment in REMPI
%lambdaprobe=305;       % wavelength of the probe to detect Iodine fragment in REMPI


% duration of the cross-correlation (fs) fixed by experimental param (rand-> uncertainity)
if (lambdapump>230)
    tauXco=50*(0.95+0.1*rand);              
else
    tauXco=200*(0.95+0.1*rand);
end


% prepare a directory for automatic recording
ck=clock;
dirname=['Pump',num2str(lambdapump),'_Probe',num2str(lambdaprobe),'_',num2str(ck(1)),num2str(ck(2),'%0.2d'),num2str(ck(3),'%0.2d'),'_',num2str(ck(4),'%0.2d'),num2str(ck(5),'%0.2d')];
mkdir(['../MyImagesVMI/',dirname]);


number=0;
%% basic Aquisition loop of the time-resolved VMI image
for delay=-500:200:2000    % write here the delay steps between the pulses

    % Aquisition of an image
    [VMIimageout,pxx,pxy]=Simu_dissociation(lambdapump,lambdaprobe,tauXco,delay);
  

    % plot a VMI image
    pcolor(pxx,pxy,VMIimageout);shading flat;axis image;colorbar;
    xlabel('Momentum (px)');ylabel('Momentum (px)');
    title(['VMI : \lambda_{pump}=',num2str(lambdapump),' nm; \lambda_{probe}=',num2str(lambdaprobe),' nm;  delay=',num2str(delay),' fs']);
    caxis([0 20]) % to fix the colorscale, give the minimum and the maximum

    % Automatic backup
    number=number+1;
    save(['../MyImagesVMI/',dirname,'/VMI',num2str(number),'.txt'],'VMIimageout','-ascii');
    tdelay(number,1)=delay;
    save(['../MyImagesVMI/',dirname,'/Time.txt'],'tdelay','-ascii');

    pause(0.1)% to see the images during the scan
end
