function [VMIimageout,pxx,pxy]=Simu_dissociation(Lambda0Pump,Lambda0Probe,tauXco,delay)
  % Lambda0Pump [nm]  = Wavelength of the pump pulse
  % Lambda0Probe [nm] = Wavelength of the probe pulse
  % tauXco [fs]       = Duration of the Cross-Correlation   
  % delay [fs]        = relative delay between the pump and the probe
  
  % A review on this dissociation, see DOI: https://doi.org/10.1007/978-3-319-02051-8_4
  
  % air conditioning fluctuation
  tt=clock;
  ACF=1+0.1*cos(2*pi*(tt(5)*60+tt(6))/20);
  tshiftexp=5;  % shift on the estimated time 0
  
  % excitation amplitude of the dissociative channel
  IAband    =ACF*exp(-4*log(2)*(266-Lambda0Pump).^2/10.^2); % estimation of the amplitude of the coupling in the A band
  IBband    =ACF*exp(-4*log(2)*(200-Lambda0Pump).^2/5.^2);  % estimation of the amplitude of the coupling in the B band
  
  ICH3      =ACF*exp(-4*log(2)*(333-Lambda0Probe).^2/5.^2);   % estimation of the efficiency of detection of the CH3 fragment
  IIodine   =ACF*exp(-4*log(2)*(305-Lambda0Probe).^2/2.^2); % estimation of the efficiency of detection of the Iodine fragment
  IIodineSO =ACF*exp(-4*log(2)*(305-Lambda0Probe).^2/2.^2); % estimation of the efficiency of detection of the Iodine fragment
  
  % Fragments mass
  mIodine=127;% mass of the iodine in atomic mass unit (amu)
  mCH3=15;    % mass of the CH3 fragment in atomic mass unit (amu)
  
  % final kinetic energy in the A band in eV
  AEI    =mCH3/(mIodine+mCH3)   *(3*1.55 - 2.41);
  AEISO  =mCH3/(mIodine+mCH3)   *(3*1.55 - 2.41-0.943);
  AECH3  =mIodine/(mIodine+mCH3)*(3*1.55 - 2.41);
  AECH3SO=mIodine/(mIodine+mCH3)*(3*1.55 - 2.41-0.943);
  
  % final kinetic energy in the B band in eV
  BEI    =mCH3/(mIodine+mCH3)   *(4*1.55 - 2.41);
  BECH3  =mIodine/(mIodine+mCH3)*(4*1.55 - 2.41);
  
  % Preparation of the temporal dynamics vectors
  dt=1; % temporal step [fs]
  tloc=[-200:dt:200];% local time
  tcentre=(length(tloc)+1)/2;
  Xco=exp(-4*log(2)*tloc.^2/tauXco^2);Xco=Xco/sum(Xco);
  TrXco=0.2*exp(-4*log(2)*(delay-tshiftexp).^2/tauXco^2);
  
  % Dynamics in the A band I channel
  Atemp1=IAband.*1./(1+exp(-(tloc-tshiftexp-120+delay)/140));
  Atemp2=conv(Atemp1,Xco,'same');
  Atemp2N=conv(Atemp1*0+1,Xco,'same');% to get the normalization
  Atemp3=Atemp2./Atemp2N;
  % plot(tloc+delay,Atemp1,tloc+delay,Atemp3); % visualization of the temporal profile
  Atemp4=Atemp3(tcentre);% Magnitude of the dissociation in the A band 
  
  % Dynamics in the A band I* channel
  Atemp1st=IAband.*1./(1+exp(-(tloc-tshiftexp-100+delay)/100));
  Atemp2st=conv(Atemp1st,Xco,'same');
  Atemp2Nst=conv(Atemp1st*0+1,Xco,'same');% to get the normalization
  Atemp3st=Atemp2st./Atemp2Nst;
  % plot(tloc+delay,Atemp1,tloc+delay,Atemp3); % visualization of the temporal profile
  Atemp4st=Atemp3st(tcentre);% Magnitude of the dissociation in the A band 
  
  
  % Dynamics in the B band (G. Gitzinger et al. JCP 132 234313 (2010))
  Btemp1=IBband.*(heaviside(tloc-tshiftexp+delay).*(1-exp(-(tloc-tshiftexp+delay)/1500)));
  Btemp2=conv(Btemp1,Xco,'same');
  Btemp2N=conv(Btemp1*0+1,Xco,'same');% to get the normalization
  Btemp3=Btemp2./Btemp2N;
  % plot(tloc+delay,Btemp1,tloc+delay,Btemp3); % visualization of the temporal profile
  Btemp4=Btemp3(tcentre); % Magnitude of the dissociation in the B band 
  BAniz=-1+0.5*(heaviside(delay).*(1-exp(-delay/1300)));
  
  Energies   =[AEI                  AEISO                AECH3             AECH3SO         BEI              BECH3           0.05];
  Intensities=[Atemp4*IIodine*0.2   Atemp4st*IIodineSO   Atemp4*ICH3*0.2   Atemp4st*ICH3   Btemp4*IIodine   Btemp4*ICH3     TrXco];
  FWHMs      =[0.1                  0.1                  0.1               0.1             0.1              0.1             0.2];
  Aniz       =[1.8                  1.9                  1.8               1.9             BAniz            BAniz           1];
  
  
  [VMIimageout,pxx,pxy]=makeVMImap(Energies,Intensities,FWHMs,Aniz);
    

  % 
  
%endfunction % use this for octave
